<?php

namespace Drupal\core_event_dispatcher\Event\Block;

use Drupal\block\BlockInterface;
use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Access\AccessResultNeutral;
use Drupal\Core\Session\AccountInterface;
use Drupal\hook_event_dispatcher\Event\EventInterface;
use Drupal\hook_event_dispatcher\HookEventDispatcherInterface;

/**
 * Class BlockAccessEvent.
 */
class BlockAccessEvent extends Event implements EventInterface {

  /**
   * The block instance.
   *
   * @var \Drupal\block\BlockInterface
   */
  protected $block;

  /**
   * The operation to be performed.
   *
   * @var string
   */
  protected $operation;

  /**
   * The user object to perform the access check operation on.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * The access result.
   *
   * @var \Drupal\Core\Access\AccessResultInterface
   */
  protected $accessResult;

  /**
   * BlockBuildAlterEvent constructor.
   */
  public function __construct(BlockInterface $block, string $operation, AccountInterface $account) {
    $this->block = $block;
    $this->operation = $operation;
    $this->account = $account;
    $this->accessResult = AccessResultNeutral::neutral();
  }

  /**
   * Get the block instance.
   *
   * @return \Drupal\block\BlockInterface
   *   The block instance.
   */
  public function getBlock(): BlockInterface {
    return $this->block;
  }

  /**
   * Get the operation to be performed.
   *
   * @return string
   *   The operation to be performed.
   */
  public function getOperation(): string {
    return $this->operation;
  }

  /**
   * Get the user object to perform the access check operation on.
   *
   * @return \Drupal\Core\Session\AccountInterface
   *   The user object to perform the access check operation on.
   */
  public function getAccount(): AccountInterface {
    return $this->account;
  }

  /**
   * Get the access result.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function getAccessResult(): AccessResultInterface {
    return $this->accessResult;
  }

  /**
   * Set the access result.
   *
   * @param \Drupal\Core\Access\AccessResultInterface $accessResult
   *   The access result.
   */
  public function setAccessResult(AccessResultInterface $accessResult): void {
    $this->accessResult = $accessResult;
  }

  /**
   * {@inheritdoc}
   */
  public function getDispatcherType(): string {
    return HookEventDispatcherInterface::BLOCK_ACCESS;
  }

}
