<?php

namespace Drupal\core_event_dispatcher\Event\Core;

use Drupal\Component\EventDispatcher\Event;
use Drupal\hook_event_dispatcher\Event\EventInterface;
use Drupal\hook_event_dispatcher\HookEventDispatcherInterface;

/**
 * Class CountriesAlterEvent.
 */
class CountriesAlterEvent extends Event implements EventInterface {

  /**
   * The associative array of countries keyed by two-letter country code.
   *
   * @var array
   */
  protected $countries;

  /**
   * CountriesAlterEvent constructor.
   *
   * @param array $countries
   *   The associative array of countries keyed by two-letter country code.
   */
  public function __construct(array &$countries) {
    $this->countries = &$countries;
  }

  /**
   * Gets the associative array of countries keyed by two-letter country code.
   *
   * @return array
   *   The associative array of countries keyed by two-letter country code.
   */
  public function &getCountries(): array {
    return $this->countries;
  }

  /**
   * {@inheritdoc}
   */
  public function getDispatcherType(): string {
    return HookEventDispatcherInterface::COUNTRIES_ALTER;
  }

}
