<?php

namespace Drupal\Tests\webform_event_dispatcher\Kernel;

use Drupal\hook_event_dispatcher\HookEventDispatcherInterface;
use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\hook_event_dispatcher\Kernel\ListenerTrait;
use Drupal\webform_event_dispatcher\Event\WebformElement\WebformElementInfoAlterEvent;

/**
 * Class WebformElementInfoAlterEventTest.
 *
 * @group hook_event_dispatcher
 * @group webform_event_dispatcher
 *
 * @requires module webform
 */
class WebformElementInfoAlterEventTest extends KernelTestBase {

  use ListenerTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'user',
    'webform',
    'hook_event_dispatcher',
    'webform_event_dispatcher',
  ];

  /**
   * Test WebformElementInfoAlterEvent.
   *
   * @throws \Exception
   */
  public function testWebformElementInfoAlterEvent(): void {
    $this->listen(HookEventDispatcherInterface::WEBFORM_ELEMENT_INFO_ALTER, 'onWebformElementInfoAlter');
    $definitions = $this->container->get('plugin.manager.webform.element')->getDefinitions();

    $this->assertArrayHasKey('#test', $definitions['textfield']);
    $this->assertEquals('test', $definitions['textfield']['#test']);
  }

  /**
   * Callback for WebformElementInfoAlterEvent.
   *
   * @param \Drupal\webform_event_dispatcher\Event\WebformElement\WebformElementInfoAlterEvent $event
   *   The event.
   */
  public function onWebformElementInfoAlter(WebformElementInfoAlterEvent $event) {
    $definitions = &$event->getDefinitions();
    $definitions['textfield']['#test'] = 'test';
  }

}
